Security vulnerabilities in pytest are rare, given it is a testing framework used for development, not used in production.

However, if you find an issue that you believe is a security risk, please report a [new Security Advisory](https://github.com/pytest-dev/pytest/security/advisories/new).
